==> golang-github-gonvenience-neat_1.3.11.orig.tar.gz: neat-1.3.11/json_test.go <==
// Copyright © 2019 The Homeport Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

package neat_test

import (
	yamlv2 "gopkg.in/yaml.v2"

	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"

	. "github.com/gonvenience/neat"
)

var _ = Describe("YAML to JSON tests", func() {
	Context("Processing valid YAML input", func() {
		It("should convert YAML to JSON", func() {
			var content yamlv2.MapSlice
			if err := yamlv2.Unmarshal([]byte(`---
name: foobar
list:
- A
- B
- C
`), &content); err != nil {
				Fail(err.Error())
			}

			result, err := ToJSONString(content)
			Expect(err).To(BeNil())

			Expect(result).To(Equal(`{"name": "foobar", "list": ["A", "B", "C"]}`))
		})
	})
})

==> golang-github-gonvenience-neat_1.3.16.orig.tar.gz: neat-1.3.16/json_test.go <==
// Copyright © 2019 The Homeport Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

package neat_test

import (
	yamlv2 "gopkg.in/yaml.v2"

	. "github.com/onsi/ginkgo/v2"
	. "github.com/onsi/gomega"

	. "github.com/gonvenience/neat"
)

var _ = Describe("YAML to JSON tests", func() {
	Context("Processing valid YAML input", func() {
		It("should convert YAML to JSON", func() {
			var content yamlv2.MapSlice
			if err := yamlv2.Unmarshal([]byte(`---
name: foobar
list:
- A
- B
- C
`), &content); err != nil {
				Fail(err.Error())
			}

			result, err := ToJSONString(content)
			Expect(err).To(BeNil())

			Expect(result).To(Equal(`{"name": "foobar", "list": ["A", "B", "C"]}`))
		})
	})
})
